datablock AudioProfile(landmineExplosionSound)
{
   filename    = "~/data/sound/QuantExp.wav";
   description = AudioClose3d;
   preload = true;
};

datablock AudioProfile(landmineFireSound)
{
   filename    = "~/data/sound/arrowHit.wav";
   description = AudioClosest3d;
   preload = true;
};

datablock ParticleData(landmineExplosionParticle)
{
	dragCoefficient      = 0.25;
	gravityCoefficient   = 0.1;
	inheritedVelFactor   = 0.2;
	constantAcceleration = 0.0;
	lifetimeMS           = 1000;
	lifetimeVarianceMS   = 300;
	textureName          = "~/data/particles/cloud";
	spinSpeed		= 10.0;
	spinRandomMin		= -50.0;
	spinRandomMax		= 50.0;
	colors[0]     = "1 0.5 0 1";
	colors[1]     = "1 0.0 0 0";
	sizes[0]      = 2;
	sizes[1]      = 2;
};

datablock ParticleEmitterData(landmineExplosionEmitter)
{
   ejectionPeriodMS = 3;
   periodVarianceMS = 0;
   ejectionVelocity = 5;
   velocityVariance = 1.0;
   ejectionOffset   = 0.0;
   thetaMin         = 0;
   thetaMax         = 90;
   phiReferenceVel  = 0;
   phiVariance      = 360;
   overrideAdvance = false;
   particles = "landmineExplosionParticle";
};

datablock ExplosionData(landmineExplosion)
{
   //explosionShape = "";
	soundProfile = landmineExplosionSound;

   lifeTimeMS = 250;

   emitter[0] = landmineExplosionEmitter;
   particleDensity = 10;
   particleRadius = 0.2;

   faceViewer     = true;
   explosionScale = "1 1 1";

   shakeCamera = false;
   camShakeFreq = "10.0 11.0 10.0";
   camShakeAmp = "1.0 1.0 1.0";
   camShakeDuration = 0.5;
   camShakeRadius = 10.0;

   // Dynamic light
   lightStartRadius = 0;
   lightEndRadius = 2;
   lightStartColor = "0.3 0.6 0.7";
   lightEndColor = "0 0 0";
};

//////////
// item //
//////////
datablock ItemData(landmine)
{
	category = "Weapon";  // Mission editor category
	className = "Tool"; // For inventory system

	 // Basic Item Properties
	shapeFile = "~/data/shapes/weapons/mountmine.dts";
	skinName = 'black';
	rotate = false;
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;

	 // Dynamic properties defined by the scripts
	pickUpName = 'Landmine';
	invName = "Landmine";
	image = landmineImage;
};


datablock ShapeBaseImageData(landmineImage)
{
   // Basic Item properties
   shapeFile = "~/data/shapes/weapons/mountmine.dts";
   skinName = 'black';
   emap = true;
    
   mountPoint = 0;
   offset = "0 0 0";
   correctMuzzleVector = true;
   className = "WeaponImage";
   item = Landmine;
   ammo = " ";
   melee = false;
   armReady = true;

   // Initial start up state
	stateName[0]                     = "Activate";
	stateTimeoutValue[0]             = 0.5;
	stateTransitionOnTimeout[0]       = "Ready";
	stateSound[0]					= weaponSwitchSound;

	stateName[1]                     = "Ready";
	stateTransitionOnTriggerDown[1]  = "Fire";
	stateAllowImageChange[1]         = true;

	stateName[2]                    = "Fire";
	stateTransitionOnTimeout[2]     = "Reload";
	stateTimeoutValue[2]            = 0.05;
	stateFire[2]                    = true;
	stateAllowImageChange[2]        = false;
	stateSequence[2]                = "Fire";
	stateScript[2]                  = "onFire";
	stateWaitForTimeout[2]			= true;
	stateSound[2]					= landmineFireSound;

	stateName[3]			= "Reload";
	stateSequence[3]                = "Reload";
	stateAllowImageChange[3]        = false;
	stateTimeoutValue[3]            = 1.0;
	stateWaitForTimeout[3]		= true;
	stateTransitionOnTimeout[3]     = "Check";

	stateName[4]			= "Check";
	stateTransitionOnTriggerUp[4]	= "StopFire";
	stateTransitionOnTriggerDown[4]	= "Fire";

	stateName[5]                    = "StopFire";
	stateTransitionOnTimeout[5]     = "Ready";
	stateTimeoutValue[5]            = 0.2;
	stateAllowImageChange[5]        = false;
	stateWaitForTimeout[5]		= true;
	//stateSequence[5]                = "Reload";
	stateScript[5]                  = "onStopFire";



};

datablock ItemData(landmineMine)
{
	shapeFile = "~/data/shapes/weapons/landmine.dts";
//	image = trans1x1roundImage;
   category = "DM";
   mass = 100;
   friction = 1.0;
   elasticity = 0.001;
   rotate = true;
   rotation = "-1 0 0 90";
   directdamage = 100;
   damagetype = '%1 got blowed to bits by %2\'s happy fun plate';
   colidable=true;
 
   // Dynamic properties defined by the scripts
   maxInventory = 0;
	pickUpName = 'Landmine... BOOM!';
	invName = 'Landmine';
};

//Static Shape
function landmineMine::onCollision(%this,%obj,%col,%fade,%pos,%normal)
{
if (%col.getdatablock() !$= "")
  if (%col.getdatablock().classname $= "armor") {
    	tbmcollison(%this,%obj,%col,%fade,%pos,%normal);
	%explosion = new explosion() {datablock=landmineExplosion; position=%obj.getPosition();};
	MissionCleanup.add(%explosion);
    %obj.delete();
    }
}

function landmineMine::onPickup(%this,%obj,%user,%amount)
{
%obj.hide(0);
}

function landmineImage::onFire(%this,%obj,%slot)
{

	%player = %obj.client.player;
	%item = nametoid(landmineMine);
	if(%item && %player)
	{
		//throw the item
        %hmm = "0 0 "@getword(%player.getscale(),2);
        %hmm = vectoradd(%hmm,"0 0 0.8");
		%muzzlepoint = Vectoradd(%player.getposition(), %hmm);
		%muzzlevector = %player.getEyeVector();
		%muzzlepoint = VectorAdd(%muzzlepoint, %muzzleVector);
		%playerRot = rotFromTransform(%player.getTransform());
		%thrownItem = new (item)()
		{
			datablock = %item;
		sourceObject     = %obj;
		sourceSlot       = %slot;
		client           = %obj.client;
		};
        %thrownItem.setscale(%player.getscale());
		MissionCleanup.add(%thrownItem);
        %thrownItem.client = %player.client;
//		%muzzleVelocity = vectoradd(VectorScale(%muzzleVector, 25),%obj.getVelocity());
//		%muzzleVelocity = vectorscale(%muzzleVelocity,%player.getscale());
		%muzzleVelocity = VectorScale(%muzzleVector, 25);
		%thrownItem.settransform(%muzzlepoint @ " " @ %playerRot);
		%thrownItem.setVelocity(%muzzleVelocity );
		%thrownItem.schedule(2*60*1000, delete);
		%thrownItem.setCollisionTimeout(%player);
//		%thrownitem.setskinname('black');

		// Explode mines if the player is over the limit
		
		%mineCount = 0;
		
		for(%i = 0; %i < MissionCleanup.GetCount(); %i++)
		{
			%testObj = MissionCleanup.getObject(%i);
			if (%testObj.dataBlock $= "landmineMine" && %testObj.client == %thrownItem.client && %testObj != %thrownItem)
			{
				%mineCount++;
				if(%mineCount >= 5)
				{
					%explosion = new explosion() {datablock=landmineExplosion; position=%testObj.getPosition();};
    				MissionCleanup.add(%explosion);
					%testObj.delete();
				}
			}
		}
    }
}

